# -*- coding: utf-8 -*-
import os, sys

from PySide import QtCore, QtGui
from PySide.QtUiTools import QUiLoader

CURRENT_DIR = os.path.abspath(os.path.dirname(__file__))

class GUI(QtGui.QMainWindow):
    """Main Window Class for Create Test Goemetry"""

    _defWidth  = 600
    _defHeight = 200
    _windowName  = "colorNodes"
    _windowTitle = "Color Nodes"

    UI_FILE = CURRENT_DIR + "/ui/gui.ui"

    def __init__(self, parent=None):
        super(GUI, self).__init__(parent)

        loader = QUiLoader()
        self.UI = loader.load(self.UI_FILE)
        self.setWindowTitle(self._windowTitle)
        self.setObjectName(self._windowName)
        self.setCentralWidget(self.UI)

        self.resize(self._defWidth, self._defHeight)

        self.initUI()

        self.setAcceptDrops(True)

    def initUI(self):
        self.UI.pushButton.setText("Change Node's Color")
        self.setSignals()


    def setSignals(self):
        self.UI.pushButton.clicked.connect(self.createColoredHip)


    ## Drop Event
    def dropEvent(self, event):
        files = []
        for url in event.mimeData().urls():
            tgtfile = unicode(url.toLocalFile())
            ext     = tgtfile.lower().split('.')[-1]
            if ext in ['hip', 'hiplc', 'hipnc']:
                files.append(tgtfile)
            else:
                self.UI.hipPathLineEdit.setText("This is not hip file.")

        if files:
            tgtfile = files[0]
            basename = os.path.abspath(tgtfile)
            self.UI.hipPathLineEdit.setText(basename)


    ## Drag Enter Event
    def dragEnterEvent(self, event):
        if event.mimeData().hasUrls():
            event.accept()
        else:
            event.ignore()


    def createColoredHip(self):
        filepath = self.UI.hipPathLineEdit.text().replace(os.path.sep, '/')

        default_color = (0.8, 0.8, 0.8)
        custom_color  = (1, 0.8, 0)

        import_nodes  = [
            "file",
            "filecache",
            "filemerge",
            "alembic",
            "alembicarchive",
        ]

        try:
            # HIPファイルをロード
            hou.hipFile.load(file_name=filepath)
        except:
            print "HIP File loading is failed. Check the hip file & path carefully."
            return

        # HIP内のすべてのノードを取得。
        nodes = hou.pwd().allSubChildren()

        for node in nodes:
            node_type_name = node.type().name().lower()
            if node_type_name in import_nodes:
                # インポート系ノードに色づけ
                node.setColor(hou.Color(custom_color))

            else:
                # インポート系以外のノードを通常の色に色づけ
                node.setColor(hou.Color(default_color))

        # "_colored"を追加リネームして保存。
        newBasename = hou.hipFile.basename().split('.')[0] + "_colored" + ".hip"
        newPath     = os.path.dirname(filepath) + '/' + newBasename
        hou.hipFile.save(file_name=newPath)


def main(*argv):
    app = QtGui.QApplication.instance()
    if app is None:
        app = QtGui.QApplication(sys.argv)

    app.setStyle('plastique')
    ui = GUI()
    ui.show()

    app.exec_()


if __name__ == '__main__':
    main(sys.argv[1:])
